@@ -123,11 +123,16 @@ class Service:
                 service_script = '{}.service'.format (name)
                 with open (service_script, 'w') as f:
                     f.write (script)
-                print ('FAILED, move {} to /etc/systemd/system\n'.format (service_script))
+                print ('install failed, you can install manually,')
+                print ('  sudo mv {} to /etc/systemd/system'.format (service_script))
+                print ("  sudo systemctl daemon-reload")
+                print ("  sudo systemctl enable {}".format (name))
+
+            else:
+                os.system ("systemctl daemon-reload")
+                os.system ("systemctl enable {}".format (name))
+                print ("service {} installed".format (name))
 
-            os.system ("systemctl daemon-reload")
-            os.system ("systemctl enable {}".format (name))
-            print ("service {} installed".format (name))
             print ("  sudo systemctl start {}".format (name))
 
         def remove (self):
